/*
 *  This file is part of M-Index library: http://disa.fi.muni.cz/m-index/
 *
 *  M-Index library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  M-Index library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with M-Index library.  If not, see <http://www.gnu.org/licenses/>.
 */
package mindex;

import java.util.Collection;
import messif.algorithms.AlgorithmMethodException;
import messif.objects.LocalAbstractObject;
import messif.objects.PrecomputedDistancesFilter;

/**
 * This M-Index pivot-permutation calculator encapsulates several PP calculators, 
 *   each for one M-Index overlay.
 * 
 * @author David Novak, Masaryk University, Brno, Czech Republic, novak.david@gmail.com
 */
public class MIndexMultiplePPCalculator extends MIndexPPCalculator {

    /** Class serial ID for serialization */
    private static final long serialVersionUID = 21080L;
    
    private final Collection<MIndexPPCalculator> mIndexPPCalculators;
    

    public MIndexMultiplePPCalculator(Collection<MIndexPPCalculator> mIndexPPCalculators) throws InstantiationException {
        super(null);
        this.mIndexPPCalculators = mIndexPPCalculators;
    }
    
    // ***************       Init object - calculate obj-pivot distance + PP  *********************  //

    @Override
    public LocalAbstractObject initPP(LocalAbstractObject object) throws AlgorithmMethodException {
        MIndexMultiplePP mIndexMultiplePP = object.getDistanceFilter(MIndexMultiplePP.class);
        if (object.getDistanceFilter(MIndexMultiplePP.class) != null) {
            return object;
        }
        mIndexMultiplePP = new MIndexMultiplePP(mIndexPPCalculators.size());
        for (MIndexPPCalculator calculator : mIndexPPCalculators) {
            calculator.initPP(object);
            PrecomputedDistancesFilter pp = (PrecomputedDistancesFilter) MetricIndexes.readMIndexPP(object);
            object.unchainFilter(pp);
            mIndexMultiplePP.addMIndexPP(pp);
        }
        object.chainFilter(mIndexMultiplePP, true);
        return object;
    }

    @Override
    public float[] initPPGetDistances(LocalAbstractObject object) throws AlgorithmMethodException {
        throw new UnsupportedOperationException("Returning all pivot distances is not supported for Multiple M-Index calculators");
    }

    @Override
    public Collection<? extends LocalAbstractObject> initPP(Collection<? extends LocalAbstractObject> objects) throws AlgorithmMethodException {
        for (LocalAbstractObject localAbstractObject : objects) {
            initPP(localAbstractObject);
        }
        return objects;
    }
        
}
