/*
 *  This file is part of M-Index library: http://disa.fi.muni.cz/m-index/
 *
 *  M-Index library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  M-Index library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with M-Index library.  If not, see <http://www.gnu.org/licenses/>.
 */
package mindex.navigation;

import java.util.List;
import messif.objects.LocalAbstractObject;

/**
 * An auxiliary class encapsulating if agile multibucket partitioning should be 
 * used during a split + number of objects that was really inserted into the bucket by the
 * operation that caused the split/
 * @author David Novak, Masaryk University, Brno, Czech Republic, novak.david@gmail.com
 */
public class SplitConfiguration {
    
    /** Number of objects that was really inserted by the last insert operation */
    private int numberOfInsertedObjects = 0;
    
    /** Flag determining if agile multi bucket partitioning should be used */
    private boolean agileMultibucketPartitioning;
    
    /** List of objects to be reinserted after the split */
    private List<? extends LocalAbstractObject> toReinsert;
    
    public SplitConfiguration(boolean agileMultibucketPartitioning, List<LocalAbstractObject> toReinsert) {
        this(agileMultibucketPartitioning, 0, toReinsert);
    }
        
    public SplitConfiguration(boolean agileMultibucketPartitioning, int numberOfInsertedObjects, List<? extends LocalAbstractObject> toReinsert) {
        this.agileMultibucketPartitioning = agileMultibucketPartitioning;
        this.numberOfInsertedObjects = numberOfInsertedObjects;
        this.toReinsert = toReinsert;
    }
    
    public boolean isAgileMultibucketPartitioning() {
        return agileMultibucketPartitioning;
    }
    
    public int getNumberOfInsertedObjects() {
    	return numberOfInsertedObjects;
    }

    public List<? extends LocalAbstractObject> getToReinsert() {
        return toReinsert;
    }        
    
}
